==> campaignion_starterkit-7.x-1.5-core.tar.gz: campaignion_starterkit-7.x-1.5/profiles/campaignion_starterkit/modules/campaignion/src/CRM/Import/Field/Field.php <==
<?php

namespace Drupal\campaignion\CRM\Import\Field;

use \Drupal\campaignion\CRM\Import\Source\SourceInterface;

/**
 * Import values into fields.
 */
class Field {
  protected $source;
  protected $field;
  public function __construct($field, $source = NULL) {
    $this->field = $field;
    $this->source = $source ? $source : $field;
    if (!is_array($this->source)) {
      $this->source = array($this->source);
    }
  }

  protected static function valueFromSource(SourceInterface $source, $keys) {
    foreach ($keys as $key) {
      if($value = $source->value($key)) {
        return $value;
      }
    }
  }
  protected function getValue(SourceInterface $source) {
    return self::valueFromSource($source, $this->source);
  }

  /**
   * Imports data from source into entity.
   *
   * @param DataSource $source
   *   Source to import from
   * @param EntityMetadataWrapper $entity
   *   Entity that stores imported data
   *
   * @return bool
   *   TRUE if at least one value of the entity was changed.
   */
  public function import(SourceInterface $source, \EntityMetadataWrapper $entity) {
    try {
      if (($value = $this->getValue($source)) && ($value = $this->preprocessField($value))) {
        if ($this->storeValue($entity, $value)) {
          return $this->setValue($entity, $value);
        } else {
          return FALSE;
        }
      }
    } catch (\EntityMetadataWrapperException $e) {
      watchdog('campaignion_webform2redhen', 'Tried to import into a non-existing field "!field".', array('!field' => $this->field), WATCHDOG_WARNING);
    }
    return FALSE;
  }

  protected function setValue(\EntityMetadataWrapper $entity, $value) {
    $entity->{$this->field}->set($value);
    return TRUE;
  }

  protected function preprocessField($value) {
    return $value;
  }

  protected function storeValue($entity, $value) {
    return $entity->{$this->field}->value() != $value;
  }
}

==> campaignion_starterkit-7.x-1.10-core.tar.gz: campaignion_starterkit-7.x-1.10/profiles/campaignion_starterkit/modules/campaignion/src/CRM/Import/Field/Field.php <==
<?php

namespace Drupal\campaignion\CRM\Import\Field;

use \Drupal\campaignion\CRM\Import\Source\SourceInterface;

/**
 * Import values into fields.
 */
class Field {
  protected $source;
  protected $field;
  public function __construct($field, $source = NULL) {
    $this->field = $field;
    $this->source = $source ? $source : $field;
    if (!is_array($this->source)) {
      $this->source = array($this->source);
    }
  }

  protected static function valueFromSource(SourceInterface $source, $keys) {
    foreach ($keys as $key) {
      if($value = $source->value($key)) {
        return $value;
      }
    }
  }
  protected function getValue(SourceInterface $source) {
    return static::valueFromSource($source, $this->source);
  }

  /**
   * Imports data from source into entity.
   *
   * @param DataSource $source
   *   Source to import from
   * @param EntityMetadataWrapper $entity
   *   Entity that stores imported data
   *
   * @return bool
   *   TRUE if at least one value of the entity was changed.
   */
  public function import(SourceInterface $source, \EntityMetadataWrapper $entity) {
    try {
      if (($value = $this->getValue($source)) && ($value = $this->preprocessField($value))) {
        if ($this->storeValue($entity, $value)) {
          return $this->setValue($entity, $value);
        } else {
          return FALSE;
        }
      }
    } catch (\EntityMetadataWrapperException $e) {
      watchdog('campaignion_webform2redhen', 'Tried to import into a non-existing field "!field".', array('!field' => $this->field), WATCHDOG_WARNING);
    }
    return FALSE;
  }

  protected function setValue(\EntityMetadataWrapper $entity, $value) {
    $entity->{$this->field}->set($value);
    return TRUE;
  }

  protected function preprocessField($value) {
    return $value;
  }

  protected function storeValue($entity, $value) {
    return $entity->{$this->field}->value() != $value;
  }
}
